==> classpath_0.12.orig.tar.gz: classpath-0.12/javax/swing/event/AncestorEvent.java <==
/* AncestorEvent.java --
   Copyright (C) 2002, 2004  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package javax.swing.event;

import java.awt.AWTEvent;
import java.awt.Container;

import javax.swing.JComponent;

/**
 * @author Andrew Selkirk
 * @author Ronald Veldema
 */
public class AncestorEvent extends AWTEvent
{
  private static final long serialVersionUID = -8079801679695605002L;
  
  public static final int ANCESTOR_ADDED = 1;
  public static final int ANCESTOR_REMOVED = 2;
  public static final int ANCESTOR_MOVED = 3;

  private JComponent sourceComponent;
  private Container ancestor;
  private Container ancestorParent;

  /**
   * @param source Source component
   * @param id ID
   * @param ancestor ancestor
   * @param ancestorParent parent ancestor
   */
  public AncestorEvent(JComponent source, int id, Container ancestor,
		       Container ancestorParent)
  {
    super(source, id);
    this.sourceComponent = source;
    this.ancestor = ancestor;
    this.ancestorParent = ancestorParent;
  }

  /**
   * Returns the ancestor of this event.
   */
  public Container getAncestor()
  {
    return ancestor;
  }

  /**
   * Returns the ancester parent of this event.
   */
  public Container getAncestorParent()
  {
    return ancestorParent;
  }

  /**
   * Returns the source of this event.
   */
  public JComponent getComponent()
  {
    return sourceComponent;
  }
}

==> classpath-0.96.1.tar.gz: classpath-0.96.1/javax/swing/event/AncestorEvent.java <==
/* AncestorEvent.java --
   Copyright (C) 2002, 2004  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package javax.swing.event;

import java.awt.AWTEvent;
import java.awt.Container;

import javax.swing.JComponent;

/**
 * @author Andrew Selkirk
 * @author Ronald Veldema
 */
public class AncestorEvent extends AWTEvent
{
  private static final long serialVersionUID = -8079801679695605002L;
  
  public static final int ANCESTOR_ADDED = 1;
  public static final int ANCESTOR_REMOVED = 2;
  public static final int ANCESTOR_MOVED = 3;

  private JComponent sourceComponent;
  private Container ancestor;
  private Container ancestorParent;

  /**
   * @param source Source component
   * @param id ID
   * @param ancestor ancestor
   * @param ancestorParent parent ancestor
   */
  public AncestorEvent(JComponent source, int id, Container ancestor,
		       Container ancestorParent)
  {
    super(source, id);
    this.sourceComponent = source;
    this.ancestor = ancestor;
    this.ancestorParent = ancestorParent;
  }

  /**
   * Returns the ancestor of this event.
   */
  public Container getAncestor()
  {
    return ancestor;
  }

  /**
   * Returns the ancester parent of this event.
   */
  public Container getAncestorParent()
  {
    return ancestorParent;
  }

  /**
   * Returns the source of this event.
   */
  public JComponent getComponent()
  {
    return sourceComponent;
  }
}
